# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/sql-face',
                'doc_host': 'https://AndreaMacarulla.github.io',
                'git_url': 'https://github.com/AndreaMacarulla/sql-face',
                'lib_path': 'sql_face'},
  'syms': { 'sql_face.alchemy': { 'sql_face.alchemy.create_cropped_images': ('alchemy.html#create_cropped_images', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.create_detectors': ('alchemy.html#create_detectors', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.create_embedding_models': ( 'alchemy.html#create_embedding_models',
                                                                                'sql_face/alchemy.py'),
                                  'sql_face.alchemy.create_face_images': ('alchemy.html#create_face_images', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.create_quality_images': ('alchemy.html#create_quality_images', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.create_quality_images_new': ( 'alchemy.html#create_quality_images_new',
                                                                                  'sql_face/alchemy.py'),
                                  'sql_face.alchemy.create_quality_models': ('alchemy.html#create_quality_models', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.fill_cropped_image_general': ( 'alchemy.html#fill_cropped_image_general',
                                                                                   'sql_face/alchemy.py'),
                                  'sql_face.alchemy.fill_cropped_image_serfiq': ( 'alchemy.html#fill_cropped_image_serfiq',
                                                                                  'sql_face/alchemy.py'),
                                  'sql_face.alchemy.get_session': ('alchemy.html#get_session', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_age': ('alchemy.html#update_age', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_angles': ('alchemy.html#update_angles', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_cropped_images': ('alchemy.html#update_cropped_images', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_embeddings_arcface': ( 'alchemy.html#update_embeddings_arcface',
                                                                                  'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_embeddings_deepface': ( 'alchemy.html#update_embeddings_deepface',
                                                                                   'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_embeddings_qmagface': ( 'alchemy.html#update_embeddings_qmagface',
                                                                                   'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_emotion': ('alchemy.html#update_emotion', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_face_images': ('alchemy.html#update_face_images', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_gender': ('alchemy.html#update_gender', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_images': ('alchemy.html#update_images', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_pose': ('alchemy.html#update_pose', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_quality_images': ('alchemy.html#update_quality_images', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_race': ('alchemy.html#update_race', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_ser_fiq': ('alchemy.html#update_ser_fiq', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_ser_fiq_old': ('alchemy.html#update_ser_fiq_old', 'sql_face/alchemy.py'),
                                  'sql_face.alchemy.update_tface': ('alchemy.html#update_tface', 'sql_face/alchemy.py')},
            'sql_face.core': {'sql_face.core.foo': ('core.html#foo', 'sql_face/core.py')},
            'sql_face.databases': { 'sql_face.databases.ChokePoint': ('databases.html#chokepoint', 'sql_face/databases.py'),
                                    'sql_face.databases.ChokePoint.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.ChokePoint.create_images': ( 'databases.html#create_images',
                                                                                     'sql_face/databases.py'),
                                    'sql_face.databases.ChokePoint.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                           'sql_face/databases.py'),
                                    'sql_face.databases.ChokePoint.get_groundtruth': ( 'databases.html#get_groundtruth',
                                                                                       'sql_face/databases.py'),
                                    'sql_face.databases.ChokePoint.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                          'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi': ('databases.html#enfsi', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi.create_images': ('databases.html#create_images', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi.fill_enfsipair': ('databases.html#fill_enfsipair', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi.fill_qry_ref': ('databases.html#fill_qry_ref', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                      'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi.get_query_reference': ( 'databases.html#get_query_reference',
                                                                                      'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                     'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015': ('databases.html#enfsi2015', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.create_images': ('databases.html#create_images', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.fill_enfsipair2015': ( 'databases.html#fill_enfsipair2015',
                                                                                         'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.fill_query': ('databases.html#fill_query', 'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.fill_reference': ( 'databases.html#fill_reference',
                                                                                     'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                          'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.get_query_reference': ( 'databases.html#get_query_reference',
                                                                                          'sql_face/databases.py'),
                                    'sql_face.databases.Enfsi2015.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                         'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase': ('databases.html#facedatabase', 'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.__eq__': ('databases.html#__eq__', 'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.__hash__': ('databases.html#__hash__', 'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.__str__': ('databases.html#__str__', 'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.create_images': ( 'databases.html#create_images',
                                                                                       'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                             'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.get_path': ('databases.html#get_path', 'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                            'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.paths_in_db': ('databases.html#paths_in_db', 'sql_face/databases.py'),
                                    'sql_face.databases.FaceDataBase.paths_not_in_db': ( 'databases.html#paths_not_in_db',
                                                                                         'sql_face/databases.py'),
                                    'sql_face.databases.ForenFace': ('databases.html#forenface', 'sql_face/databases.py'),
                                    'sql_face.databases.ForenFace.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.ForenFace.create_images': ('databases.html#create_images', 'sql_face/databases.py'),
                                    'sql_face.databases.ForenFace.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                          'sql_face/databases.py'),
                                    'sql_face.databases.ForenFace.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                         'sql_face/databases.py'),
                                    'sql_face.databases.ForenFace.set_attributes': ( 'databases.html#set_attributes',
                                                                                     'sql_face/databases.py'),
                                    'sql_face.databases.LFW': ('databases.html#lfw', 'sql_face/databases.py'),
                                    'sql_face.databases.LFW.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.LFW.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                    'sql_face/databases.py'),
                                    'sql_face.databases.LFW.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                   'sql_face/databases.py'),
                                    'sql_face.databases.SCFace': ('databases.html#scface', 'sql_face/databases.py'),
                                    'sql_face.databases.SCFace.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.SCFace._types_to_folders': ( 'databases.html#_types_to_folders',
                                                                                     'sql_face/databases.py'),
                                    'sql_face.databases.SCFace.create_images': ('databases.html#create_images', 'sql_face/databases.py'),
                                    'sql_face.databases.SCFace.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                       'sql_face/databases.py'),
                                    'sql_face.databases.SCFace.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                      'sql_face/databases.py'),
                                    'sql_face.databases.SCFace.set_glasses_beard_gender': ( 'databases.html#set_glasses_beard_gender',
                                                                                            'sql_face/databases.py'),
                                    'sql_face.databases.SCFace.set_yaw_pitch_dist': ( 'databases.html#set_yaw_pitch_dist',
                                                                                      'sql_face/databases.py'),
                                    'sql_face.databases.SCFace.type_from_path': ('databases.html#type_from_path', 'sql_face/databases.py'),
                                    'sql_face.databases.UTKFace': ('databases.html#utkface', 'sql_face/databases.py'),
                                    'sql_face.databases.UTKFace.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.UTKFace.create_images': ('databases.html#create_images', 'sql_face/databases.py'),
                                    'sql_face.databases.UTKFace.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                        'sql_face/databases.py'),
                                    'sql_face.databases.UTKFace.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                       'sql_face/databases.py'),
                                    'sql_face.databases.UTKFace.set_age_gender_race': ( 'databases.html#set_age_gender_race',
                                                                                        'sql_face/databases.py'),
                                    'sql_face.databases.XQLFW': ('databases.html#xqlfw', 'sql_face/databases.py'),
                                    'sql_face.databases.XQLFW.__init__': ('databases.html#__init__', 'sql_face/databases.py'),
                                    'sql_face.databases.XQLFW.get_all_image_paths': ( 'databases.html#get_all_image_paths',
                                                                                      'sql_face/databases.py'),
                                    'sql_face.databases.XQLFW.identity_from_path': ( 'databases.html#identity_from_path',
                                                                                     'sql_face/databases.py'),
                                    'sql_face.databases.get_image_db': ('databases.html#get_image_db', 'sql_face/databases.py')},
            'sql_face.faceangles': { 'sql_face.faceangles.FaceParser': ('faceangles.html#faceparser', 'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.__get_body_face_key_landmarks': ( 'faceangles.html#__get_body_face_key_landmarks',
                                                                                                       'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.__get_face_bounding_box': ( 'faceangles.html#__get_face_bounding_box',
                                                                                                 'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.__get_face_key_landmarks': ( 'faceangles.html#__get_face_key_landmarks',
                                                                                                  'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.__get_head_angles': ( 'faceangles.html#__get_head_angles',
                                                                                           'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.__init__': ('faceangles.html#__init__', 'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.__normalized_to_pixel_coordinates': ( 'faceangles.html#__normalized_to_pixel_coordinates',
                                                                                                           'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.__truncate_to_valid_rect': ( 'faceangles.html#__truncate_to_valid_rect',
                                                                                                  'sql_face/faceangles.py'),
                                     'sql_face.faceangles.FaceParser.detect_faces_lms_ang': ( 'faceangles.html#detect_faces_lms_ang',
                                                                                              'sql_face/faceangles.py'),
                                     'sql_face.faceangles.classify_angle': ('faceangles.html#classify_angle', 'sql_face/faceangles.py'),
                                     'sql_face.faceangles.compute_angles': ('faceangles.html#compute_angles', 'sql_face/faceangles.py'),
                                     'sql_face.faceangles.compute_pose': ('faceangles.html#compute_pose', 'sql_face/faceangles.py')},
            'sql_face.qmagface': { 'sql_face.qmagface.IBasicBlock': ('qmagface.html#ibasicblock', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.IBasicBlock.__init__': ('qmagface.html#__init__', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.IBasicBlock.forward': ('qmagface.html#forward', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.IResNet': ('qmagface.html#iresnet', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.IResNet.__init__': ('qmagface.html#__init__', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.IResNet._make_layer': ('qmagface.html#_make_layer', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.IResNet.forward': ('qmagface.html#forward', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.NetworkBuilder_inf': ('qmagface.html#networkbuilder_inf', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.NetworkBuilder_inf.__init__': ('qmagface.html#__init__', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.NetworkBuilder_inf.forward': ('qmagface.html#forward', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface._iresnet': ('qmagface.html#_iresnet', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.builder_inf': ('qmagface.html#builder_inf', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.clean_dict_inf': ('qmagface.html#clean_dict_inf', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.compute_qmagface_embeddings': ( 'qmagface.html#compute_qmagface_embeddings',
                                                                                      'sql_face/qmagface.py'),
                                   'sql_face.qmagface.conv1x1': ('qmagface.html#conv1x1', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.conv3x3': ('qmagface.html#conv3x3', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.iresnet100': ('qmagface.html#iresnet100', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.iresnet18': ('qmagface.html#iresnet18', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.iresnet34': ('qmagface.html#iresnet34', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.iresnet50': ('qmagface.html#iresnet50', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.load_dict_inf': ('qmagface.html#load_dict_inf', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.load_features': ('qmagface.html#load_features', 'sql_face/qmagface.py'),
                                   'sql_face.qmagface.load_model': ('qmagface.html#load_model', 'sql_face/qmagface.py')},
            'sql_face.serfiq': { 'sql_face.serfiq.MtcnnDetector': ('serfiq.html#mtcnndetector', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.__init__': ('serfiq.html#__init__', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.calibrate_box': ('serfiq.html#calibrate_box', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.convert_to_square': ('serfiq.html#convert_to_square', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.detect_face': ('serfiq.html#detect_face', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.detect_face_limited': ( 'serfiq.html#detect_face_limited',
                                                                                        'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.extract_image_chips': ( 'serfiq.html#extract_image_chips',
                                                                                        'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.find_tfrom_between_shapes': ( 'serfiq.html#find_tfrom_between_shapes',
                                                                                              'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.list2colmatrix': ('serfiq.html#list2colmatrix', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.pad': ('serfiq.html#pad', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.MtcnnDetector.slice_index': ('serfiq.html#slice_index', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.SER_FIQ': ('serfiq.html#ser_fiq', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.SER_FIQ.__init__': ('serfiq.html#__init__', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.SER_FIQ.apply_mtcnn': ('serfiq.html#apply_mtcnn', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.SER_FIQ.get_score': ('serfiq.html#get_score', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.adjust_input': ('serfiq.html#adjust_input', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.detect_first_stage': ('serfiq.html#detect_first_stage', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.detect_first_stage_warpper': ( 'serfiq.html#detect_first_stage_warpper',
                                                                                 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.generate_bbox': ('serfiq.html#generate_bbox', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.get_serfiq_model': ('serfiq.html#get_serfiq_model', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.nms': ('serfiq.html#nms', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.parse_lst_line': ('serfiq.html#parse_lst_line', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.preprocess': ('serfiq.html#preprocess', 'sql_face/serfiq.py'),
                                 'sql_face.serfiq.read_image': ('serfiq.html#read_image', 'sql_face/serfiq.py')},
            'sql_face.sqldb': { 'sql_face.sqldb.SQLDataBase': ('sqldb.html#sqldatabase', 'sql_face/sqldb.py'),
                                'sql_face.sqldb.SQLDataBase.__init__': ('sqldb.html#__init__', 'sql_face/sqldb.py'),
                                'sql_face.sqldb.SQLDataBase.create_tables': ('sqldb.html#create_tables', 'sql_face/sqldb.py'),
                                'sql_face.sqldb.SQLDataBase.update_tables': ('sqldb.html#update_tables', 'sql_face/sqldb.py'),
                                'sql_face.sqldb.get_output_dir': ('sqldb.html#get_output_dir', 'sql_face/sqldb.py')},
            'sql_face.tables': { 'sql_face.tables.Age': ('tables.html#age', 'sql_face/tables.py'),
                                 'sql_face.tables.Age.age2enum': ('tables.html#age2enum', 'sql_face/tables.py'),
                                 'sql_face.tables.CPFrame': ('tables.html#cpframe', 'sql_face/tables.py'),
                                 'sql_face.tables.CPFrame.get_image': ('tables.html#get_image', 'sql_face/tables.py'),
                                 'sql_face.tables.CroppedImage': ('tables.html#croppedimage', 'sql_face/tables.py'),
                                 'sql_face.tables.CroppedImage.get_aligned_image': ('tables.html#get_aligned_image', 'sql_face/tables.py'),
                                 'sql_face.tables.CroppedImage.get_cropped_image': ('tables.html#get_cropped_image', 'sql_face/tables.py'),
                                 'sql_face.tables.Detector': ('tables.html#detector', 'sql_face/tables.py'),
                                 'sql_face.tables.Distance': ('tables.html#distance', 'sql_face/tables.py'),
                                 'sql_face.tables.EmbeddingModel': ('tables.html#embeddingmodel', 'sql_face/tables.py'),
                                 'sql_face.tables.Emotion': ('tables.html#emotion', 'sql_face/tables.py'),
                                 'sql_face.tables.EnfsiImage': ('tables.html#enfsiimage', 'sql_face/tables.py'),
                                 'sql_face.tables.EnfsiMixin': ('tables.html#enfsimixin', 'sql_face/tables.py'),
                                 'sql_face.tables.EnfsiMixin.image_id': ('tables.html#image_id', 'sql_face/tables.py'),
                                 'sql_face.tables.EnfsiPair': ('tables.html#enfsipair', 'sql_face/tables.py'),
                                 'sql_face.tables.EnfsiPair2015': ('tables.html#enfsipair2015', 'sql_face/tables.py'),
                                 'sql_face.tables.EnfsiVideoFrame': ('tables.html#enfsivideoframe', 'sql_face/tables.py'),
                                 'sql_face.tables.FaceImage': ('tables.html#faceimage', 'sql_face/tables.py'),
                                 'sql_face.tables.Gender': ('tables.html#gender', 'sql_face/tables.py'),
                                 'sql_face.tables.Image': ('tables.html#image', 'sql_face/tables.py'),
                                 'sql_face.tables.Image.get_category': ('tables.html#get_category', 'sql_face/tables.py'),
                                 'sql_face.tables.Image.get_fi_category': ('tables.html#get_fi_category', 'sql_face/tables.py'),
                                 'sql_face.tables.Image.get_im_category': ('tables.html#get_im_category', 'sql_face/tables.py'),
                                 'sql_face.tables.Image.get_image': ('tables.html#get_image', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair': ('tables.html#pair', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair.__init__': ('tables.html#__init__', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair.get_category': ('tables.html#get_category', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair.get_n_common_attributes': ( 'tables.html#get_n_common_attributes',
                                                                                   'sql_face/tables.py'),
                                 'sql_face.tables.Pair.is_same': ('tables.html#is_same', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair.is_valid': ('tables.html#is_valid', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair.make_cropped_pair': ('tables.html#make_cropped_pair', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair.make_face_image_pair': ('tables.html#make_face_image_pair', 'sql_face/tables.py'),
                                 'sql_face.tables.Pair.pair_category_str': ('tables.html#pair_category_str', 'sql_face/tables.py'),
                                 'sql_face.tables.Pitch': ('tables.html#pitch', 'sql_face/tables.py'),
                                 'sql_face.tables.QualityGroup': ('tables.html#qualitygroup', 'sql_face/tables.py'),
                                 'sql_face.tables.QualityImage': ('tables.html#qualityimage', 'sql_face/tables.py'),
                                 'sql_face.tables.QualityModel': ('tables.html#qualitymodel', 'sql_face/tables.py'),
                                 'sql_face.tables.Race': ('tables.html#race', 'sql_face/tables.py'),
                                 'sql_face.tables.Roll': ('tables.html#roll', 'sql_face/tables.py'),
                                 'sql_face.tables.SCFaceMixin': ('tables.html#scfacemixin', 'sql_face/tables.py'),
                                 'sql_face.tables.SCFaceMixin.image_id': ('tables.html#image_id', 'sql_face/tables.py'),
                                 'sql_face.tables.SCImage': ('tables.html#scimage', 'sql_face/tables.py'),
                                 'sql_face.tables.VideoFrame': ('tables.html#videoframe', 'sql_face/tables.py'),
                                 'sql_face.tables.VideoMixin': ('tables.html#videomixin', 'sql_face/tables.py'),
                                 'sql_face.tables.VideoMixin.get_image': ('tables.html#get_image', 'sql_face/tables.py'),
                                 'sql_face.tables.VideoMixin.image_id': ('tables.html#image_id', 'sql_face/tables.py'),
                                 'sql_face.tables.Yaw': ('tables.html#yaw', 'sql_face/tables.py')},
            'sql_face.tface': { 'sql_face.tface.Backbone': ('tface.html#backbone', 'sql_face/tface.py'),
                                'sql_face.tface.Backbone.__init__': ('tface.html#__init__', 'sql_face/tface.py'),
                                'sql_face.tface.Backbone._initialize_weights': ('tface.html#_initialize_weights', 'sql_face/tface.py'),
                                'sql_face.tface.Backbone.forward': ('tface.html#forward', 'sql_face/tface.py'),
                                'sql_face.tface.Bottleneck': ('tface.html#bottleneck', 'sql_face/tface.py'),
                                'sql_face.tface.Flatten': ('tface.html#flatten', 'sql_face/tface.py'),
                                'sql_face.tface.Flatten.forward': ('tface.html#forward', 'sql_face/tface.py'),
                                'sql_face.tface.R50': ('tface.html#r50', 'sql_face/tface.py'),
                                'sql_face.tface.bottleneck_IR': ('tface.html#bottleneck_ir', 'sql_face/tface.py'),
                                'sql_face.tface.bottleneck_IR.__init__': ('tface.html#__init__', 'sql_face/tface.py'),
                                'sql_face.tface.bottleneck_IR.forward': ('tface.html#forward', 'sql_face/tface.py'),
                                'sql_face.tface.compute_tf_quality': ('tface.html#compute_tf_quality', 'sql_face/tface.py'),
                                'sql_face.tface.get_block': ('tface.html#get_block', 'sql_face/tface.py'),
                                'sql_face.tface.get_blocks': ('tface.html#get_blocks', 'sql_face/tface.py'),
                                'sql_face.tface.get_network': ('tface.html#get_network', 'sql_face/tface.py'),
                                'sql_face.tface.l2_norm': ('tface.html#l2_norm', 'sql_face/tface.py'),
                                'sql_face.tface.network': ('tface.html#network', 'sql_face/tface.py'),
                                'sql_face.tface.preprocess_tf_img': ('tface.html#preprocess_tf_img', 'sql_face/tface.py')}}}